# Audit Rating Web Component

A React-based web component for displaying audit ratings and performance metrics for applications. This component can be easily integrated into any web application using either npm or a CDN.

English | [简体中文](./README.zh-CN.md)

## Features

- Display comprehensive performance, experience, and best practice metrics
- Show detailed resource information for failed items
- Responsive design that works on all devices
- Internationalization support (English and Chinese)
- Customizable through data attributes
- Easy integration as a web component

## Installation

### Using npm/yarn/pnpm

```bash
npm install @ray-js/audit-rating-web-component
# or
yarn add @ray-js/audit-rating-web-component
# or
pnpm add @ray-js/audit-rating-web-component
```

### Using CDN

You can include the component directly from a CDN:

```html
<!-- Include React and ReactDOM (production versions) -->
<script src="https://unpkg.com/react@18/umd/react.production.min.js" crossorigin></script>
<script src="https://unpkg.com/react-dom@18/umd/react-dom.production.min.js" crossorigin></script>

<!-- Include the Audit Rating Component -->
<script src="https://unpkg.com/@ray-js/audit-rating-web-component/dist/audit-rating-component.umd.cjs"></script>
<link rel="stylesheet" href="https://unpkg.com/@ray-js/audit-rating-web-component/dist/audit-rating-component.css">
```

## Usage

### Basic Usage

After including the script, you can use the custom element in your HTML:

```html
<!-- Method 1: Using the custom element directly -->
<audit-rating-box data-language="en"></audit-rating-box>

<!-- Method 2: Using a div with ID "audit-rating-box" -->
<div id="audit-rating-box" data-language="en"></div>
```

### Providing Data

You can provide data in two ways:

#### 1. Using a script tag with JSON data

```html
<!-- Add this in your HTML head -->
<script type="application/json" id="miniprogram-audit-rating-data">
  {
    "basicInfo": {
      "brand": "iPhone",
      "model": "iPhone 7 Plus",
      "jssdkVersion": "2.27.0",
      "network": "wifi",
      "miniprogramId": "your-miniprogram-id",
      "miniprogramName": "Your App Name",
      "versionCode": "1.0.0"
    },
    "source": [
      {
        "id": "performance",
        "score": 85,
        "level": "good",
        "tasks": [...]
      },
      // More data items...
    ]
  }
</script>

<!-- Then use the component -->
<audit-rating-box data-language="en"></audit-rating-box>
```

#### 2. Using data attributes

```html
<audit-rating-box 
  data-language="en"
  data-source='[{"id":"performance","score":85,"level":"good","tasks":[...]}]'
  data-basic-info='{"brand":"iPhone","model":"iPhone 7 Plus","jssdkVersion":"2.27.0","network":"wifi","miniprogramId":"your-id","miniprogramName":"Your App","versionCode":"1.0.0"}'>
</audit-rating-box>
```

#### 3. Creating the element dynamically

```html
<div id="container"></div>

<script>
  document.addEventListener('DOMContentLoaded', function() {
    const container = document.getElementById('container');
    if (container) {
      const customElement = document.createElement('audit-rating-box');
      customElement.setAttribute('data-language', 'en');
      container.appendChild(customElement);
    }
  });
</script>
```

## Configuration

The component accepts the following data attributes:

- `data-language`: The language to use ("en" or "zh", defaults to "en")
- `data-source`: JSON string containing the audit source data
- `data-basic-info`: JSON string containing basic information about the app being audited

## Data Format

### Basic Info

The `basicInfo` object should contain the following properties:

```json
{
  "brand": "iPhone",
  "model": "iPhone 7 Plus",
  "jssdkVersion": "2.27.0",
  "network": "wifi",
  "miniprogramId": "your-miniprogram-id",
  "miniprogramName": "Your App Name",
  "versionCode": "1.0.0"
}
```

### Source Data

The `source` array contains performance metrics and other audit data:

```json
[
  {
    "id": "performance",
    "score": 85,
    "level": "good",
    "tasks": [...]
  },
  // More metrics...
]
```

## Development

```bash
# Install dependencies
pnpm install

# Start development server
pnpm dev

# Build for production
pnpm build
```

## License

MIT
